==> ejc-jlcost-api-3.0.0-20240529.011647-99-sources.jar: com/ejianc/business/jlcost/payout/vo/ContractClauseVO.java <==
package com.ejianc.business.jlcost.payout.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 支出合同-合同关键条款
 * 
 * @author generator
 * 
 */
public class ContractClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long clauseId; // 合同条款名称Id
    private String clauseName; // 合同条款名称
    private String clauseContent; // 合同条款内容
    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键
    private Integer necessaryStatus; // 是否必填：0-否，1-是
    private String memo;

    public Long getClauseId() {
        return clauseId;
    }

    public void setClauseId(Long clauseId) {
        this.clauseId = clauseId;
    }
    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}

==> ejc-jlcost-api-3.0.0-20240927.063156-246-sources.jar: com/ejianc/business/jlcost/payout/vo/ContractClauseVO.java <==
package com.ejianc.business.jlcost.payout.vo;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 支出合同-合同关键条款
 * 
 * @author generator
 * 
 */
public class ContractClauseVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long clauseId; // 合同条款名称Id
    private String clauseName; // 合同条款名称
    private String clauseContent; // 合同条款内容
    private Long contractId; // 所属合同Id
    private Long changeId; // 变更主键
    private Long changeBid; // 变更子表主键
    private Integer necessaryStatus; // 是否必填：0-否，1-是
    private String memo;
    private String errorMsg;//导入用
    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public Long getClauseId() {
        return clauseId;
    }

    public void setClauseId(Long clauseId) {
        this.clauseId = clauseId;
    }
    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }
    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }
    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }
    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }
    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }
    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }

    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
}
